==> react-image-annotate-cn-1.0.3.tgz: package/SettingsDialog/index.js <==
import React from "react";
import Dialog from "@mui/material/Dialog";
import DialogTitle from "@mui/material/DialogTitle";
import DialogContent from "@mui/material/DialogContent";
import DialogActions from "@mui/material/DialogActions";
import Button from "@mui/material/Button";
import Survey from "material-survey/components/Survey";
import { useSettings } from "../SettingsProvider";
export var SettingsDialog = function SettingsDialog(_ref) {
  var open = _ref.open,
      onClose = _ref.onClose;
  var settings = useSettings();
  return /*#__PURE__*/React.createElement(Dialog, {
    open: open || false,
    onClose: onClose
  }, /*#__PURE__*/React.createElement(DialogTitle, null, "\u8BBE\u7F6E"), /*#__PURE__*/React.createElement(DialogContent, {
    style: {
      minWidth: 400
    }
  }, /*#__PURE__*/React.createElement(Survey, {
    variant: "flat",
    noActions: true,
    defaultAnswers: settings,
    onQuestionChange: function onQuestionChange(q, a, answers) {
      return settings.changeSetting(q, a);
    },
    form: {
      questions: [{
        type: "boolean",
        title: "显示十字光标",
        name: "showCrosshairs"
      }, {
        type: "boolean",
        title: "显示突出显示框",
        name: "showHighlightBox"
      }, {
        type: "boolean",
        title: "WASD模式",
        name: "wasdMode"
      }, {
        type: "dropdown",
        title: "视频播放速度",
        name: "videoPlaybackSpeed",
        defaultValue: "1x",
        choices: ["0.25x", "0.5x", "1x", "2x"]
      }]
    }
  })), /*#__PURE__*/React.createElement(DialogActions, null, /*#__PURE__*/React.createElement(Button, {
    onClick: onClose
  }, "\u5173\u95ED")));
};
export default SettingsDialog;

==> react-image-annotate-cn-1.0.5.tgz: package/SettingsDialog/index.js <==
import React from "react";
import Dialog from "@mui/material/Dialog";
import DialogTitle from "@mui/material/DialogTitle";
import DialogContent from "@mui/material/DialogContent";
import DialogActions from "@mui/material/DialogActions";
import Button from "@mui/material/Button";
import Survey from "material-survey/components/Survey";
import { useSettings } from "../SettingsProvider";
export var SettingsDialog = function SettingsDialog(_ref) {
  var open = _ref.open,
      onClose = _ref.onClose;
  var settings = useSettings();
  return React.createElement(Dialog, {
    open: open || false,
    onClose: onClose
  }, React.createElement(DialogTitle, null, "\u8BBE\u7F6E"), React.createElement(DialogContent, {
    style: {
      minWidth: 400
    }
  }, React.createElement(Survey, {
    variant: "flat",
    noActions: true,
    defaultAnswers: settings,
    onQuestionChange: function onQuestionChange(q, a, answers) {
      return settings.changeSetting(q, a);
    },
    form: {
      questions: [{
        type: "boolean",
        title: "显示十字光标",
        name: "showCrosshairs"
      }, {
        type: "boolean",
        title: "显示突出显示框",
        name: "showHighlightBox"
      }, {
        type: "boolean",
        title: "WASD模式",
        name: "wasdMode"
      }, {
        type: "dropdown",
        title: "视频播放速度",
        name: "videoPlaybackSpeed",
        defaultValue: "1x",
        choices: ["0.25x", "0.5x", "1x", "2x"]
      }]
    }
  })), React.createElement(DialogActions, null, React.createElement(Button, {
    onClick: onClose
  }, "\u5173\u95ED")));
};
export default SettingsDialog;
